@@ -231,8 +231,8 @@ KIPIInterface::~KIPIInterface()
 
 static bool actionLessThan(QAction* a1, QAction* a2)
 {
-    QString a1Text = a1->text().replace("&", "");
-    QString a2Text = a2->text().replace("&", "");
+    QString a1Text = a1->text().replace("&", QString());
+    QString a2Text = a2->text().replace("&", QString());
     return QString::compare(a1Text, a2Text, Qt::CaseInsensitive) < 0;
 }
 
