@@ -25,16 +25,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QDateTime>
 #include <QDesktopWidget>
 #include <QLabel>
-#include <QTimer>
 #include <QShortcut>
-#include <QSplitter>
 #include <QSlider>
+#include <QSplitter>
 #include <QStackedWidget>
+#include <QTimer>
 #include <QUndoGroup>
 #include <QVBoxLayout>
 
 // KDE
 #include <KIO/NetAccess>
+#include <KActionCategory>
 #include <KActionCollection>
 #include <KAction>
 #include <KApplication>
@@ -43,16 +44,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KFileDialog>
 #include <KFileItem>
 #include <KGlobalSettings>
-#include <KMenuBar>
 #include <KLocale>
+#include <KMenuBar>
 #include <KMessageBox>
 #include <KNotificationRestrictions>
 #include <KProtocolManager>
 #include <KStatusBar>
+#include <KStandardDirs>
 #include <KStandardGuiItem>
 #include <KStandardShortcut>
-#include <KActionCategory>
-#include <KProtocolManager>
 #include <KToggleFullScreenAction>
 #include <KToolBar>
 #include <KUrl>
@@ -212,13 +212,18 @@ struct MainWindow::Private
 
     void setupWidgets()
     {
-        // FIXME: Can we rely on ObsidianCoast to always be there?
         {
             KSharedConfigPtr config;
             QString name = GwenviewConfig::fullScreenColorScheme();
-            if (name.contains('/')) {
+            if (name.isEmpty()) {
+                // Default color scheme
+                QString path = KStandardDirs::locate("data", "gwenview/color-schemes/fullscreen.colors");
+                config = KSharedConfig::openConfig(path);
+            } else if (name.contains('/')) {
+                // Full path to a .colors file
                 config = KSharedConfig::openConfig(name);
             } else {
+                // Standard KDE color scheme
                 config = KSharedConfig::openConfig(QString("color-schemes/%1.colors").arg(name), KConfig::FullConfig, "data");
             }
             mFullScreenPalette = KGlobalSettings::createApplicationPalette(config);
