@@ -116,7 +116,7 @@ struct ThumbnailPagePrivate : public Ui_ThumbnailPage
 
         PreviewItemDelegate* delegate = new PreviewItemDelegate(mThumbnailView);
         delegate->setThumbnailDetails(PreviewItemDelegate::FileNameDetail);
-        delegate->setContextBarMode(PreviewItemDelegate::SelectionOnlyContextBar);
+        delegate->setContextBarActions(PreviewItemDelegate::SelectionAction);
         mThumbnailView->setItemDelegate(delegate);
 
         // Colors
