@@ -33,6 +33,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QCursor>
 #include <QGraphicsSceneEvent>
 #include <QPainter>
+#include <QPropertyAnimation>
+#include <QTimer>
 
 namespace Gwenview
 {
@@ -40,6 +42,8 @@ namespace Gwenview
 static qreal MIN_SIZE = 72;
 static qreal VIEW_OFFSET = MIN_SIZE / 4;
 
+static int AUTOHIDE_DELAY = 2000;
+
 /**
  * Returns a QRectF whose coordinates are rounded to completely contains rect
  */
@@ -52,6 +56,8 @@ struct BirdEyeViewPrivate
 {
     BirdEyeView* q;
     DocumentView* mDocView;
+    QPropertyAnimation* mOpacityAnim;
+    QTimer* mAutoHideTimer;
     QRectF mVisibleRect;
     QPointF mLastDragPos;
 
@@ -59,6 +65,39 @@ struct BirdEyeViewPrivate
     {
         q->setCursor(mVisibleRect.contains(pos) ? Qt::OpenHandCursor : Qt::ArrowCursor);
     }
+
+    void updateVisibility()
+    {
+        bool visible;
+        if (!mDocView->canZoom() || mDocView->zoomToFit()) {
+            // No need to show
+            visible = false;
+        } else if (mDocView->isAnimated()) {
+            // Do not show while animated
+            visible = false;
+        } else if (mVisibleRect == q->boundingRect()) {
+            // All of the image is visible
+            visible = false;
+        } else if (q->isUnderMouse() || !mLastDragPos.isNull()) {
+            // User is interacting or about to interact with birdeyeview
+            visible = true;
+        } else if (mAutoHideTimer->isActive()) {
+            // User triggered some activity recently (move mouse, scroll, zoom)
+            visible = true;
+        } else {
+            // No recent activity
+            visible = false;
+        }
+        qreal wantedOpacity = visible ? 1 : 0;
+        if (!qFuzzyCompare(wantedOpacity, q->opacity())) {
+            mOpacityAnim->setEndValue(wantedOpacity);
+            mOpacityAnim->start();
+        }
+
+        if (visible) {
+            mAutoHideTimer->start();
+        }
+    }
 };
 
 BirdEyeView::BirdEyeView(DocumentView* docView)
@@ -70,12 +109,22 @@ BirdEyeView::BirdEyeView(DocumentView* docView)
     setFlag(ItemIsSelectable);
     setCursor(Qt::ArrowCursor);
     setAcceptHoverEvents(true);
-    adjustGeometry();
 
-    connect(docView->document().data(), SIGNAL(metaInfoUpdated()), SLOT(adjustGeometry()));
-    connect(docView, SIGNAL(zoomChanged(qreal)), SLOT(adjustGeometry()));
-    connect(docView, SIGNAL(zoomToFitChanged(bool)), SLOT(adjustGeometry()));
-    connect(docView, SIGNAL(positionChanged()), SLOT(adjustVisibleRect()));
+    d->mOpacityAnim = new QPropertyAnimation(this, "opacity", this);
+
+    d->mAutoHideTimer = new QTimer(this);
+    d->mAutoHideTimer->setSingleShot(true);
+    d->mAutoHideTimer->setInterval(AUTOHIDE_DELAY);
+    connect(d->mAutoHideTimer, SIGNAL(timeout()), SLOT(slotAutoHideTimeout()));
+
+    // Hide ourself by default, to avoid startup flashes (if we let updateOpacity
+    // update opacity, it will do so through an animation)
+    setOpacity(0);
+
+    connect(docView->document().data(), SIGNAL(metaInfoUpdated()), SLOT(slotZoomOrSizeChanged()));
+    connect(docView, SIGNAL(zoomChanged(qreal)), SLOT(slotZoomOrSizeChanged()));
+    connect(docView, SIGNAL(zoomToFitChanged(bool)), SLOT(slotZoomOrSizeChanged()));
+    connect(docView, SIGNAL(positionChanged()), SLOT(slotPositionChanged()));
 }
 
 BirdEyeView::~BirdEyeView()
@@ -86,10 +135,8 @@ BirdEyeView::~BirdEyeView()
 void BirdEyeView::adjustGeometry()
 {
     if (!d->mDocView->canZoom() || d->mDocView->zoomToFit()) {
-        hide();
         return;
     }
-    show();
     QSize size = d->mDocView->document()->size();
     size.scale(MIN_SIZE, MIN_SIZE, Qt::KeepAspectRatioByExpanding);
     QRectF docViewRect = d->mDocView->boundingRect();
@@ -103,8 +150,6 @@ void BirdEyeView::adjustGeometry()
     );
     setGeometry(alignedRectF(geom));
     adjustVisibleRect();
-
-    setVisible(d->mVisibleRect != boundingRect());
 }
 
 void BirdEyeView::adjustVisibleRect()
@@ -121,7 +166,31 @@ void BirdEyeView::adjustVisibleRect()
         QPointF(d->mDocView->position()) / viewZoom * bevZoom,
         (d->mDocView->size() / viewZoom).boundedTo(docSize) * bevZoom);
     d->mVisibleRect = alignedRectF(rect);
+}
+
+void BirdEyeView::slotAutoHideTimeout()
+{
+    d->updateVisibility();
+}
+
+void BirdEyeView::slotZoomOrSizeChanged()
+{
+    if (!d->mDocView->canZoom() || d->mDocView->zoomToFit()) {
+        d->updateVisibility();
+        return;
+    }
+    adjustGeometry();
     update();
+    d->mAutoHideTimer->start();
+    d->updateVisibility();
+}
+
+void BirdEyeView::slotPositionChanged()
+{
+    adjustVisibleRect();
+    update();
+    d->mAutoHideTimer->start();
+    d->updateVisibility();
 }
 
 inline void drawTransparentRect(QPainter* painter, const QRectF& rect, const QColor& color)
@@ -142,6 +211,17 @@ void BirdEyeView::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWid
     drawTransparentRect(painter, d->mVisibleRect, Qt::white);
 }
 
+void BirdEyeView::onMouseMoved()
+{
+    d->mAutoHideTimer->start();
+    d->updateVisibility();
+}
+
+void BirdEyeView::slotIsAnimatedChanged()
+{
+    d->updateVisibility();
+}
+
 void BirdEyeView::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
     if (d->mVisibleRect.contains(event->pos())) {
@@ -174,6 +254,13 @@ void BirdEyeView::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
     }
     d->updateCursor(event->pos());
     d->mLastDragPos = QPointF();
+    d->mAutoHideTimer->start();
+}
+
+void BirdEyeView::hoverEnterEvent(QGraphicsSceneHoverEvent* /*event*/)
+{
+    d->mAutoHideTimer->stop();
+    d->updateVisibility();
 }
 
 void BirdEyeView::hoverMoveEvent(QGraphicsSceneHoverEvent* event)
@@ -183,4 +270,10 @@ void BirdEyeView::hoverMoveEvent(QGraphicsSceneHoverEvent* event)
     }
 }
 
+void BirdEyeView::hoverLeaveEvent(QGraphicsSceneHoverEvent* /*event*/)
+{
+    d->mAutoHideTimer->start();
+    d->updateVisibility();
+}
+
 } // namespace
