@@ -296,10 +296,11 @@ struct DocumentViewPrivate
             QObject::connect(anim, SIGNAL(finished()),
                             q, SLOT(slotFadeInFinished()));
         }
+        QObject::connect(anim, SIGNAL(finished()), q, SIGNAL(isAnimatedChanged()));
         anim->setDuration(DocumentView::AnimDuration);
-        anim->start(QAbstractAnimation::DeleteWhenStopped);
-
         mFadeAnimation = anim;
+        q->isAnimatedChanged();
+        anim->start(QAbstractAnimation::DeleteWhenStopped);
     }
 };
 
@@ -322,7 +323,7 @@ DocumentView::DocumentView(QGraphicsScene* scene)
     scene->addItem(this);
 
     d->setupHud();
-    d->setCurrentAdapter(new MessageViewAdapter);
+    d->setCurrentAdapter(new EmptyAdapter);
 }
 
 DocumentView::~DocumentView()
@@ -409,11 +410,6 @@ void DocumentView::finishOpenUrl()
     d->updateCaption();
 }
 
-bool DocumentView::isEmpty() const
-{
-    return qobject_cast<EmptyAdapter*>(d->mAdapter.data());
-}
-
 void DocumentView::loadAdapterConfig()
 {
     d->mAdapter->loadConfig();
@@ -595,7 +591,7 @@ qreal DocumentView::minimumZoom() const
 {
     // There is no point zooming out less than zoomToFit, but make sure it does
     // not get too small either
-    return qMax(0.001, qMin(double(d->mAdapter->computeZoomToFit()), 1.));
+    return qBound(qreal(0.001), d->mAdapter->computeZoomToFit(), qreal(1.));
 }
 
 void DocumentView::setCompareMode(bool compare)
@@ -665,7 +661,7 @@ void DocumentView::setGeometry(const QRectF& rect)
     QGraphicsWidget::setGeometry(rect);
     d->resizeAdapterWidget();
     if (d->mBirdEyeView) {
-        d->mBirdEyeView->adjustGeometry();
+        d->mBirdEyeView->slotZoomOrSizeChanged();
     }
 }
 
@@ -684,8 +680,10 @@ void DocumentView::moveToAnimated(const QRect& rect)
     anim->setStartValue(geometry());
     anim->setEndValue(rect);
     anim->setDuration(DocumentView::AnimDuration);
-    anim->start(QAbstractAnimation::DeleteWhenStopped);
+    connect(anim, SIGNAL(finished()), SIGNAL(isAnimatedChanged()));
     d->mMoveAnimation = anim;
+    isAnimatedChanged();
+    anim->start(QAbstractAnimation::DeleteWhenStopped);
 }
 
 QPropertyAnimation* DocumentView::fadeIn()
@@ -704,10 +702,19 @@ void DocumentView::slotFadeInFinished()
     fadeInFinished(this);
 }
 
+bool DocumentView::isAnimated() const
+{
+    return d->mMoveAnimation || d->mFadeAnimation;
+}
+
 bool DocumentView::sceneEventFilter(QGraphicsItem*, QEvent* event)
 {
     if (event->type() == QEvent::GraphicsSceneMousePress) {
         QMetaObject::invokeMethod(this, "emitFocused", Qt::QueuedConnection);
+    } else if (event->type() == QEvent::GraphicsSceneHoverMove) {
+        if (d->mBirdEyeView) {
+            d->mBirdEyeView->onMouseMoved();
+        }
     }
     return false;
 }
