@@ -262,28 +262,25 @@ struct ImageMetaInfoModelPrivate
         it = container.begin(),
         end = container.end();
 
-        for (; it != end; ++it) {
-            try {
-                QString key = QString::fromUtf8(it->key().c_str());
-                QString label = QString::fromLocal8Bit(it->tagLabel().c_str());
-                std::ostringstream stream;
-                stream << *it;
-                QString value = QString::fromLocal8Bit(stream.str().c_str());
+        if (it == end) {
+            return;
+        }
 
-                EntryHash::iterator hashIt = hash.find(key);
-                if (hashIt != hash.end()) {
-                    hashIt.value()->appendValue(value);
-                } else {
-                    hash.insert(key, new MetaInfoGroup::Entry(key, label, value));
-                }
-            } catch (const Exiv2::Error& error) {
-                kWarning() << "Failed to read some meta info:" << error.what();
+        for (; it != end; ++it) {
+            QString key = QString::fromUtf8(it->key().c_str());
+            QString label = QString::fromLocal8Bit(it->tagLabel().c_str());
+            std::ostringstream stream;
+            stream << *it;
+            QString value = QString::fromLocal8Bit(stream.str().c_str());
+
+            EntryHash::iterator hashIt = hash.find(key);
+            if (hashIt != hash.end()) {
+                hashIt.value()->appendValue(value);
+            } else {
+                hash.insert(key, new MetaInfoGroup::Entry(key, label, value));
             }
         }
 
-        if (hash.isEmpty()) {
-            return;
-        }
         q->beginInsertRows(parent, 0, hash.size() - 1);
         Q_FOREACH(MetaInfoGroup::Entry * entry, hash) {
             group->addEntry(entry);
@@ -337,7 +334,7 @@ void ImageMetaInfoModel::setImageSize(const QSize& size)
                              "(%1MP)", megaPixelsString);
         }
     } else {
-        imageSize = "-";
+        imageSize = '-';
     }
     d->setGroupEntryValue(GeneralGroup, "General.ImageSize", imageSize);
 }
