@@ -431,7 +431,6 @@ void ThumbnailLoadJob::start()
     if (mItems.isEmpty()) {
         LOG("Nothing to do");
         emitResult();
-        delete this;
         return;
     }
 
@@ -490,12 +489,10 @@ void ThumbnailLoadJob::determineNextIcon()
         // Done
         LOG("emitting result");
         emitResult();
-        delete this;
         return;
     }
 
-    mCurrentItem = mItems.first();
-    mItems.pop_front();
+    mCurrentItem = mItems.takeFirst();
     LOG("mCurrentItem.url=" << mCurrentItem.url());
 
     // First, stat the orig file
@@ -510,7 +507,7 @@ void ThumbnailLoadJob::determineNextIcon()
         if (KDE::stat(mCurrentUrl.toLocalFile(), &buff) == 0)  {
             directStatOk = true;
             mOriginalTime = buff.st_mtime;
-            QTimer::singleShot(0, this, SLOT(checkThumbnail()));
+            QMetaObject::invokeMethod(this, "checkThumbnail", Qt::QueuedConnection);
         }
     }
     if (!directStatOk) {
@@ -623,17 +620,17 @@ void ThumbnailLoadJob::checkThumbnail()
             if (ok) {
                 size = QSize(width, height);
             } else {
-                LOG("Thumbnail for" << mOriginalUri << "does not contain correct image size information");
+                kWarning() << "Thumbnail for" << mOriginalUri << "does not contain correct image size information";
                 KFileMetaInfo fmi(mCurrentUrl);
                 if (fmi.isValid()) {
                     KFileMetaInfoItem item = fmi.item("Dimensions");
                     if (item.isValid()) {
                         size = item.value().toSize();
                     } else {
-                        LOG("KFileMetaInfoItem for" << mOriginalUri << "did not get image size information");
+                        kWarning() << "KFileMetaInfoItem for" << mOriginalUri << "did not get image size information";
                     }
                 } else {
-                    LOG("Could not get a valid KFileMetaInfo instance for" << mOriginalUri);
+                    kWarning() << "Could not get a valid KFileMetaInfo instance for" << mOriginalUri;
                 }
             }
             emitThumbnailLoaded(thumb, size);
